==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/client/render/model/FrostWandItemModel.java <==
package com.github.thedeathlycow.frostiful.client.render.model;

import com.github.thedeathlycow.frostiful.Frostiful;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3879;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.*;

/**
 * Made with Block Bench
 */
@Environment(EnvType.CLIENT)
public class FrostWandItemModel extends class_3879 {
    public static final class_2960 TEXTURE = Frostiful.id("textures/entity/frost_wand.png");

    public FrostWandItemModel(class_630 root) {
        super(root, class_1921::method_23580);
    }

    public static class_5607 getTexturedModelData() {
        class_5609 modelData = new class_5609();
        class_5610 modelPartData = modelData.method_32111();
        class_5610 root = modelPartData.method_32117("root", class_5606.method_32108(), class_5603.method_32090(0.0F, 24.0F, 0.0F));

        class_5610 rod = root.method_32117("rod", class_5606.method_32108().method_32101(32, 9).method_32098(-1.0F, -1.0F, -1.0F, 2.0F, 1.0F, 2.0F, new class_5605(0.0F))
                .method_32101(20, 8).method_32098(-2.0F, -5.0F, -2.0F, 4.0F, 4.0F, 4.0F, new class_5605(0.0F))
                .method_32101(0, 0).method_32098(-1.0F, -33.0F, -1.0F, 2.0F, 28.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 0.0F, 0.0F));

        class_5610 top = root.method_32117("top", class_5606.method_32108().method_32101(8, 0).method_32098(-3.0F, -1.0F, -3.0F, 6.0F, 2.0F, 6.0F, new class_5605(0.0F))
                .method_32101(0, 32).method_32098(-2.0F, 1.0F, -2.0F, 4.0F, 3.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -37.0F, 0.0F));

        class_5610 icicles = top.method_32117("icicles", class_5606.method_32108().method_32101(20, 25).method_32098(-3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F))
                .method_32101(20, 20).method_32098(3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 0.0F, 0.0F));

        class_5610 south_r1 = icicles.method_32117("south_r1", class_5606.method_32108().method_32101(20, 10).method_32098(-3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F))
                .method_32101(20, 15).method_32098(3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.0F, 1.5708F, 0.0F));

        class_5610 icicle = root.method_32117("icicle", class_5606.method_32108(), class_5603.method_32090(0.0F, -26.0F, 0.0F));

        class_5610 main = icicle.method_32117("main", class_5606.method_32108(), class_5603.method_32090(0.0F, -6.0F, 0.0F));

        class_5610 cube_r1 = main.method_32117("cube_r1", class_5606.method_32108().method_32101(8, 8).method_32098(-3.0F, -26.0F, 0.0F, 6.0F, 17.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, 0.0F, 0.0F, -0.7854F, 0.0F));

        class_5610 cube_r2 = main.method_32117("cube_r2", class_5606.method_32108().method_32101(8, 8).method_32098(-3.0F, -26.0F, 0.0F, 6.0F, 17.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, 0.0F, 0.0F, 0.7854F, 0.0F));

        class_5610 sides = icicle.method_32117("sides", class_5606.method_32108(), class_5603.method_32090(0.0F, 0.0F, 0.0F));

        class_5610 west_r1 = sides.method_32117("west_r1", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, -16.0F, 0.0F, -0.1745F, 1.5708F, 0.0F));

        class_5610 east_r1 = sides.method_32117("east_r1", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, -16.0F, 0.0F, -0.1745F, -1.5708F, 0.0F));

        class_5610 south_r2 = sides.method_32117("south_r2", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -16.0F, 4.0F, -0.1745F, 0.0F, 0.0F));

        class_5610 north_r1 = sides.method_32117("north_r1", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -16.0F, -4.0F, 0.1745F, 0.0F, 0.0F));
        return class_5607.method_32110(modelData, 64, 64);
    }
}

==> frostiful-2.2.9%2B1.21.9-sources.jar: com/github/thedeathlycow/frostiful/client/render/model/FrostWandItemModel.java <==
package com.github.thedeathlycow.frostiful.client.render.model;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.client.render.state.FrostologerEntityRenderState;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.*;

/**
 * Made with Block Bench
 */
@Environment(EnvType.CLIENT)
public class FrostWandItemModel extends class_583<FrostologerEntityRenderState> {
    public static final class_2960 TEXTURE = Frostiful.id("textures/entity/frost_wand.png");

    public FrostWandItemModel(class_630 root) {
        super(root, class_1921::method_23580);
    }

    public static class_5607 getTexturedModelData() {
        class_5609 modelData = new class_5609();
        class_5610 modelPartData = modelData.method_32111();
        class_5610 root = modelPartData.method_32117("root", class_5606.method_32108(), class_5603.method_32090(0.0F, 24.0F, 0.0F));

        class_5610 rod = root.method_32117("rod", class_5606.method_32108().method_32101(32, 9).method_32098(-1.0F, -1.0F, -1.0F, 2.0F, 1.0F, 2.0F, new class_5605(0.0F))
                .method_32101(20, 8).method_32098(-2.0F, -5.0F, -2.0F, 4.0F, 4.0F, 4.0F, new class_5605(0.0F))
                .method_32101(0, 0).method_32098(-1.0F, -33.0F, -1.0F, 2.0F, 28.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 0.0F, 0.0F));

        class_5610 top = root.method_32117("top", class_5606.method_32108().method_32101(8, 0).method_32098(-3.0F, -1.0F, -3.0F, 6.0F, 2.0F, 6.0F, new class_5605(0.0F))
                .method_32101(0, 32).method_32098(-2.0F, 1.0F, -2.0F, 4.0F, 3.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -37.0F, 0.0F));

        class_5610 icicles = top.method_32117("icicles", class_5606.method_32108().method_32101(20, 25).method_32098(-3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F))
                .method_32101(20, 20).method_32098(3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 0.0F, 0.0F));

        class_5610 south_r1 = icicles.method_32117("south_r1", class_5606.method_32108().method_32101(20, 10).method_32098(-3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F))
                .method_32101(20, 15).method_32098(3.0F, 1.0F, -3.0F, 0.0F, 5.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.0F, 1.5708F, 0.0F));

        class_5610 icicle = root.method_32117("icicle", class_5606.method_32108(), class_5603.method_32090(0.0F, -26.0F, 0.0F));

        class_5610 main = icicle.method_32117("main", class_5606.method_32108(), class_5603.method_32090(0.0F, -6.0F, 0.0F));

        class_5610 cube_r1 = main.method_32117("cube_r1", class_5606.method_32108().method_32101(8, 8).method_32098(-3.0F, -26.0F, 0.0F, 6.0F, 17.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, 0.0F, 0.0F, -0.7854F, 0.0F));

        class_5610 cube_r2 = main.method_32117("cube_r2", class_5606.method_32108().method_32101(8, 8).method_32098(-3.0F, -26.0F, 0.0F, 6.0F, 17.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, 0.0F, 0.0F, 0.7854F, 0.0F));

        class_5610 sides = icicle.method_32117("sides", class_5606.method_32108(), class_5603.method_32090(0.0F, 0.0F, 0.0F));

        class_5610 west_r1 = sides.method_32117("west_r1", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, -16.0F, 0.0F, -0.1745F, 1.5708F, 0.0F));

        class_5610 east_r1 = sides.method_32117("east_r1", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, -16.0F, 0.0F, -0.1745F, -1.5708F, 0.0F));

        class_5610 south_r2 = sides.method_32117("south_r2", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -16.0F, 4.0F, -0.1745F, 0.0F, 0.0F));

        class_5610 north_r1 = sides.method_32117("north_r1", class_5606.method_32108().method_32101(32, 16).method_32098(-3.0F, -6.0F, 0.0F, 6.0F, 9.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -16.0F, -4.0F, 0.1745F, 0.0F, 0.0F));
        return class_5607.method_32110(modelData, 64, 64);
    }
}
